diff -purN u-boot-1.0.0/common/cmd_flash.c u-boot-1.0.0-a/common/cmd_flash.c
--- u-boot-1.0.0/common/cmd_flash.c	Tue Oct 14 14:43:56 2003
+++ u-boot-1.0.0-a/common/cmd_flash.c	Mon Dec  1 12:59:14 2003
@@ -36,6 +36,44 @@
 
 extern flash_info_t flash_info[];	/* info for FLASH chips */
 
+
+void print_flash_error(int rcode)
+{
+  switch (rcode) {
+  case ERR_OK:
+    printf("OK");
+    break;
+  case ERR_TIMOUT:
+    printf("TIME OUT");
+    break;
+  case ERR_NOT_ERASED:
+    printf("NOT ERASED");
+    break;
+  case ERR_PROTECTED:
+    printf("PROTECTED");
+    break;
+  case ERR_INVAL:
+    printf("INVALID");
+    break;
+  case ERR_ALIGN:
+    printf("ALIGNMENT");
+    break;
+  case ERR_UNKNOWN_FLASH_VENDOR:
+    printf("UNKNOWN VENDOR");
+    break;
+  case ERR_UNKNOWN_FLASH_TYPE:
+    printf("UNKNOWN TYPE");
+    break;
+  case ERR_PROG_ERROR:
+    printf("PROGRAMMING ERROR");
+    break;
+
+  default:
+    printf("UNKNOWN");
+    break;
+  }
+}
+
 /*
  * The user interface starts numbering for Flash banks with 1
  * for historical reasons.
@@ -219,7 +257,12 @@ int do_flerase (cmd_tbl_t *cmdtp, int fl
 			printf ("Erase Flash Bank # %ld ", bank);
 			info = &flash_info[bank-1];
 			rcode = flash_erase (info, 0, info->sector_count-1);
-		}
+			if( rcode != ERR_OK ) {
+			       printf("ERROR[0x%X]: ",rcode);
+			       print_flash_error(rcode);
+			       printf("\n");
+			}
+		}		
 		return rcode;
 	}
 
@@ -231,6 +274,11 @@ int do_flerase (cmd_tbl_t *cmdtp, int fl
 		printf ("Erase Flash Sectors %d-%d in Bank # %d ",
 			sect_first, sect_last, (info-flash_info)+1);
 		rcode = flash_erase(info, sect_first, sect_last);
+		if( rcode != ERR_OK ) {
+		        printf("ERROR[0x%X]: ",rcode);
+			print_flash_error(rcode);
+			printf("\n");
+		}
 		return rcode;
 	}
 
@@ -249,6 +297,11 @@ int do_flerase (cmd_tbl_t *cmdtp, int fl
 		printf ("Erase Flash Bank # %ld ", bank);
 		info = &flash_info[bank-1];
 		rcode = flash_erase (info, 0, info->sector_count-1);
+		if( rcode != ERR_OK ) {
+		        printf("ERROR[0x%X]: ",rcode);
+			print_flash_error(rcode);
+			printf("\n");
+		}
 		return rcode;
 	}
 
@@ -290,6 +343,11 @@ int flash_sect_erase (ulong addr_first, 
 						info->start[s_last[bank]+1] - 1,
 					bank+1);
 				rcode = flash_erase (info, s_first[bank], s_last[bank]);
+				if( rcode != ERR_OK ) {
+				  printf("ERROR[0x%X]: ",rcode);
+				  print_flash_error(rcode);
+				  printf("\n");
+				}
 			}
 		}
 		printf ("Erased %d sectors\n", erased);
